"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _reactAdmin = require("react-admin");

var _queryString = require("query-string");

var _constants = require("./lib/constants");

// data provider for react-admin
// created 25-mar-2019 by rich braun <docker@instantlinux.net>
// rewritten 24-feb-2020
function urlPrefix(resource) {
  const fallbackUrl = process.env.REACT_APP_API_URL;
  var res = JSON.parse(sessionStorage.getItem('resource_endpoints'));
  return "".concat(res && resource in res ? res[resource] : fallbackUrl, "/").concat(resource);
}

function httpClient(url, options = {}) {
  const uid = sessionStorage.getItem('uid');
  const token = sessionStorage.getItem('token');
  options.headers = new Headers({
    Accept: 'application/json',
    Authorization: 'Basic ' + btoa(uid + ':' + token)
  }); // console.log('httpClient ' + url + ', opt=' + JSON.stringify(options));

  return _reactAdmin.fetchUtils.fetchJson(url, { ...options,
    credentials: 'include'
  });
}

function cacheSeconds(seconds = _constants.apiCacheSec) {
  const validUntil = new Date();
  validUntil.setTime(validUntil.getTime() + seconds * 1000);
  return validUntil;
}

const dataProvider = {
  getList: (resource, params) => {
    const query = {
      limit: params.pagination.perPage,
      offset: (params.pagination.page - 1) * params.pagination.perPage,
      status: ['active']
    };

    if (params.sort) {
      query.sort = params.sort.field + ':' + params.sort.order.toLowerCase();
    }

    if (params.filter.hasOwnProperty('q')) {
      params.filter.name = params.filter.q + '%';
      delete params.filter.q;
    } else if (params.filter.hasOwnProperty('name') && params.filter.name[0] !== '%') {
      params.filter.name = "%".concat(params.filter.name, "%");
    }

    if (Object.keys(params.filter).length > 0) {
      query.filter = JSON.stringify(params.filter);
    }

    return httpClient("".concat(urlPrefix(resource), "?").concat((0, _queryString.stringify)(query))).then(({
      json
    }) => ({
      data: json.items,
      total: json.count,
      validUntil: cacheSeconds()
    }));
  },
  getOne: (resource, params) => httpClient("".concat(urlPrefix(resource), "/").concat(params.id)).then(({
    json
  }) => ({
    data: json,
    validUntil: cacheSeconds()
  })),
  getMany: (resource, params) => {
    const query = {
      filter: JSON.stringify({
        id: params.ids
      }),
      limit: params.ids.length
    };
    return httpClient("".concat(urlPrefix(resource), "?").concat((0, _queryString.stringify)(query))).then(({
      json
    }) => ({
      data: json.items,
      total: json.count,
      validUntil: cacheSeconds()
    }));
  },
  getManyReference: (resource, params) => {
    const {
      field,
      order
    } = params.sort;
    var filter = { ...params.filter,
      [params.target]: params.id
    };

    if (params.target in params.filter) {
      // Not documented but filter-override appears to be required
      filter[params.target] = params.filter[params.target];
    }

    const query = {
      limit: params.pagination.perPage,
      offset: (params.pagination.page - 1) * params.pagination.perPage,
      sort: field + ':' + order.toLowerCase(),
      filter: JSON.stringify(filter)
    };
    return httpClient("".concat(urlPrefix(resource), "?").concat((0, _queryString.stringify)(query))).then(({
      json
    }) => ({
      data: json.items,
      total: json.count,
      validUntil: cacheSeconds()
    }));
  },
  update: (resource, params) => {
    _constants.excludeFields.forEach(function (val) {
      delete params.data[val];
    });

    if (resource === 'picture') {
      _constants.excludeExifFields.forEach(function (val) {
        delete params.data[val];
      });
    }

    const options = {
      method: 'PUT',
      body: JSON.stringify(params.data)
    };
    return httpClient("".concat(urlPrefix(resource), "/").concat(params.id), options).then(({
      json
    }) => ({
      data: json
    }));
  },
  create: (resource, params) => httpClient("".concat(urlPrefix(resource)), {
    method: 'POST',
    body: JSON.stringify(params.data)
  }).then(({
    json
  }) => ({
    data: json
  })),
  delete: (resource, params) => httpClient("".concat(urlPrefix(resource), "/").concat(params.id), {
    method: 'DELETE'
  }).then(({
    json
  }) => ({
    data: json
  })),
  deleteMany: (resource, params) => httpClient("".concat(urlPrefix(resource), "/").concat(params.ids.join()), {
    method: 'DELETE'
  }).then(({
    json
  }) => ({
    data: json
  }))
};
var _default = dataProvider;
exports.default = _default;